LocalPipelineIo
===============

.. currentmodule:: toasty.pipeline.local_io

.. autoclass:: LocalPipelineIo
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LocalPipelineIo.check_exists
      ~LocalPipelineIo.get_item
      ~LocalPipelineIo.list_items
      ~LocalPipelineIo.put_item

   .. rubric:: Methods Documentation

   .. automethod:: check_exists
   .. automethod:: get_item
   .. automethod:: list_items
   .. automethod:: put_item
